@@ -15,12 +15,12 @@ __author__ = (
 )
 
 import math
-import numpy
-import scipy.spatial
-import scipy.constants
-from scipy.spatial.distance import euclidean
-from math import pi, cos, sin
+from math import cos, pi, sin
 
+import numpy
+import scipy.constants
+import scipy.spatial
+from scipy.spatial.distance import euclidean
 
 __all__ = [
     "RADIUS_EARTH_KM",
@@ -67,13 +67,11 @@ def arcdist(pt0, pt1, radius=RADIUS_EARTH_KM):
 
     Examples
     --------
-    
     >>> pt0 = (0, 0)
     >>> pt1 = (180, 0)
     >>> d = arcdist(pt0, pt1, RADIUS_EARTH_MILES)
     >>> d == math.pi * RADIUS_EARTH_MILES
     True
-    
     """
 
     dist = linear2arcdist(euclidean(toXYZ(pt0), toXYZ(pt1)), radius)
@@ -84,7 +82,7 @@ def arcdist(pt0, pt1, radius=RADIUS_EARTH_KM):
 def arcdist2linear(arc_dist, radius=RADIUS_EARTH_KM):
     """Convert an arc distance (spherical earth)
     to a linear distance (R3) in the unit sphere.
-    
+
     Parameters
     ----------
     arc_dist : float
@@ -95,24 +93,22 @@ def arcdist2linear(arc_dist, radius=RADIUS_EARTH_KM):
         radius in miles, ``RADIUS_EARTH_MILES`` (``3958.76``)
         is also an option.
         Source: http://nssdc.gsfc.nasa.gov/planetary/factsheet/earthfact.html
-    
+
     Returns
     -------
     linear_dist : float
         The linear distance conversion of ``arc_dist``.
-    
+
     Examples
     --------
-    
     >>> pt0 = (0, 0)
     >>> pt1 = (180, 0)
     >>> d = arcdist(pt0, pt1, RADIUS_EARTH_MILES)
     >>> d == math.pi * RADIUS_EARTH_MILES
     True
-    
+
     >>> arcdist2linear(d, RADIUS_EARTH_MILES)
     2.0
-    
     """
 
     circumference = 2 * math.pi * radius
@@ -126,7 +122,7 @@ def arcdist2linear(arc_dist, radius=RADIUS_EARTH_KM):
 def linear2arcdist(linear_dist, radius=RADIUS_EARTH_KM):
     """Convert a linear distance in the unit sphere
     (R3) to an arc distance based on supplied radius.
-    
+
     Parameters
     ----------
     linear_dist : float
@@ -137,26 +133,24 @@ def linear2arcdist(linear_dist, radius=RADIUS_EARTH_KM):
         radius in miles, ``RADIUS_EARTH_MILES`` (``3958.76``)
         is also an option.
         Source: http://nssdc.gsfc.nasa.gov/planetary/factsheet/earthfact.html
-    
+
     Returns
     -------
     arc_dist : float
         The arc distance conversion of ``linear_dist``.
-    
+
     Raises
     ------
     ValueError
         Raised when ``linear_dist`` exceeds the diameter of the unit sphere.
-    
+
     Examples
     --------
-    
     >>> pt0 = (0, 0)
     >>> pt1 = (180, 0)
     >>> d = arcdist(pt0, pt1, RADIUS_EARTH_MILES)
     >>> d == linear2arcdist(2.0, radius=RADIUS_EARTH_MILES)
     True
-    
     """
 
     if linear_dist == float("inf"):
@@ -166,16 +160,16 @@ def linear2arcdist(linear_dist, radius=RADIUS_EARTH_KM):
         raise ValueError(msg)
     else:
         circumference = 2 * math.pi * radius
-        a2 = linear_dist ** 2
+        a2 = linear_dist**2
         theta = math.degrees(math.acos((2 - a2) / (2.0)))
         arc_dist = (theta * circumference) / 360.0
 
     return arc_dist
 
 
-def toXYZ(pt):
+def toXYZ(pt):  # noqa N802
     """Convert a point's latitude and longitude to x,y,z.
-    
+
     Parameters
     ----------
     pt : tuple
@@ -185,7 +179,6 @@ def toXYZ(pt):
     -------
     x, y, z : tuple
         A point in form (x, y, z).
-    
     """
 
     phi, theta = list(map(math.radians, pt))
@@ -197,19 +190,18 @@ def toXYZ(pt):
     return x, y, z
 
 
-def toLngLat(xyz):
+def toLngLat(xyz):  # noqa N802
     """Convert a point's x,y,z to latitude and longitude.
-    
+
     Parameters
     ----------
     xyz : tuple
         A point assumed to be in form (x,y,z).
-    
+
     Returns
     -------
     phi, theta : tuple
         A point in form (phi, theta) [y,x].
-    
     """
 
     x, y, z = xyz
@@ -228,7 +220,7 @@ def toLngLat(xyz):
 
 def brute_knn(pts, k, mode="arc", radius=RADIUS_EARTH_KM):
     """Computes a brute-force :math:`k` nearest neighbors.
-    
+
     Parameters
     ----------
     pts : list
@@ -244,12 +236,11 @@ def brute_knn(pts, k, mode="arc", radius=RADIUS_EARTH_KM):
         radius in miles, ``RADIUS_EARTH_MILES`` (``3958.76``)
         is also an option.
         Source: http://nssdc.gsfc.nasa.gov/planetary/factsheet/earthfact.html
-    
+
     Returns
     -------
     w : dict
         A neighbor ID lookup.
-    
     """
 
     n = len(pts)
@@ -298,7 +289,6 @@ def fast_knn(pts, k, return_dist=False, radius=RADIUS_EARTH_KM):
         A neighbor ID lookup.
     wd : dict
         A neighbor distance lookup (optional).
-
     """
 
     pts = numpy.array(pts)
@@ -341,7 +331,6 @@ def fast_threshold(pts, dist, radius=RADIUS_EARTH_KM):
         A neighbor distance lookup where the key is the ID
         of a point and the value is a list of IDs for other
         points within ``dist`` of the key point,
-
     """
 
     d = arcdist2linear(dist, radius)
@@ -350,9 +339,9 @@ def fast_threshold(pts, dist, radius=RADIUS_EARTH_KM):
     wd = {}
 
     for i in range(len(pts)):
-        l = r[i]
-        l.remove(i)
-        wd[i] = l
+        l_ = r[i]
+        l_.remove(i)
+        wd[i] = l_
 
     return wd
 
@@ -372,14 +361,12 @@ def lonlat(pointslist):
 
     Examples
     --------
-    
     >>> points = [
     ...     (41.981417, -87.893517), (41.980396, -87.776787), (41.980906, -87.696450)
     ... ]
     >>> newpoints = lonlat(points)
     >>> newpoints
     [(-87.893517, 41.981417), (-87.776787, 41.980396), (-87.69645, 41.980906)]
-
     """
 
     newpts = [(i[1], i[0]) for i in pointslist]
@@ -402,10 +389,8 @@ def haversine(x):
 
     Examples
     --------
-    
     >>> haversine(math.pi) # is 180 in radians, hence sin of 90 = 1
     1.0
-
     """
 
     x = math.sin(x / 2)
@@ -441,7 +426,6 @@ def radangle(p0, p1):
 
     Examples
     --------
-    
     >>> p0 = (-87.893517, 41.981417)
     >>> p1 = (-87.519295, 41.657498)
     >>> radangle(p0, p1)
@@ -449,10 +433,8 @@ def radangle(p0, p1):
 
     Notes
     -----
-    
     Uses haversine formula, function haversine and degree to radian
     conversion lambda function ``d2r``.
-
     """
 
     x0, y0 = d2r(p0[0]), d2r(p0[1])
@@ -491,20 +473,17 @@ def harcdist(p0, p1, lonx=True, radius=RADIUS_EARTH_KM):
 
     Examples
     --------
-    
     >>> p0 = (-87.893517, 41.981417)
     >>> p1 = (-87.519295, 41.657498)
     >>> harcdist(p0, p1)
     47.52873002976876
-    
+
     >>> harcdist(p0, p1, radius=None)
     0.007460167953189258
 
     Notes
     -----
-    
     Uses the ``radangle`` function to compute radian angle.
-
     """
 
     if not (lonx):
@@ -521,7 +500,7 @@ def harcdist(p0, p1, lonx=True, radius=RADIUS_EARTH_KM):
 
 
 def geointerpolate(p0, p1, t, lonx=True):
-    """Finds a point on a sphere along the great circle distance between
+    r"""Finds a point on a sphere along the great circle distance between
     two points on a sphere also known as a way point in great circle navigation.
 
     Parameters
@@ -546,17 +525,15 @@ def geointerpolate(p0, p1, t, lonx=True):
 
     Examples
     --------
-    
     >>> p0 = (-87.893517, 41.981417)
     >>> p1 = (-87.519295, 41.657498)
     >>> geointerpolate(p0, p1, 0.1)             # using lon-lat
     (-87.85592403438788, 41.949079912574796)
-    
+
     >>> p3 = (41.981417, -87.893517)
     >>> p4 = (41.657498, -87.519295)
     >>> geointerpolate(p3, p4, 0.1, lonx=False) # using lat-lon
     (41.949079912574796, -87.85592403438788)
-
     """
 
     if not (lonx):
@@ -612,7 +589,6 @@ def geogrid(pup, pdown, k, lonx=True):
 
     Examples
     --------
-    
     >>> pup = (42.023768, -87.946389)       # Arlington Heights, IL
     >>> pdown = (41.644415, -87.524102)     # Hammond, IN
     >>> geogrid(pup,pdown, 3, lonx=False)
@@ -632,13 +608,9 @@ def geogrid(pup, pdown, k, lonx=True):
      (41.64458672568646, -87.80562679171955),
      (41.64458672568646, -87.66486420828045),
      (41.644415, -87.524102)]
-
     """
 
-    if lonx:
-        corners = [pup, pdown]
-    else:
-        corners = lonlat([pup, pdown])
+    corners = [pup, pdown] if lonx else lonlat([pup, pdown])
 
     tpoints = [float(i) / k for i in range(k)[1:]]
     leftcorners = [corners[0], (corners[0][0], corners[1][1])]
