@@ -7,18 +7,27 @@ This module provides functionality for working with these example datasets.
 """
 
 
-import pandas as pd
-from .base import example_manager
-from .remotes import datasets as remote_datasets
-from .builtin import datasets as builtin_datasets
 from typing import Union
 
+import pandas as pd
+
+from .base import Example, example_manager
+from .builtin import LocalExample
+from .builtin import datasets as builtin_datasets
+from .remotes import datasets as remote_datasets
 
 available_datasets = builtin_datasets.copy()
 available_datasets.update(remote_datasets.datasets)
 
-__all__ = ["get_path", "available", "explain", "fetch_all",
-           "get_url", "load_example", "summary"]
+__all__ = [
+    "get_path",
+    "available",
+    "explain",
+    "fetch_all",
+    "get_url",
+    "load_example",
+    "summary",
+]
 
 example_manager.add_examples(available_datasets)
 
@@ -32,8 +41,8 @@ def fetch_all():
         example = datasets[name]
         try:
             example.download()
-        except:
-            print("Example not downloaded: {}".format(name))
+        except:  # noqa E722
+            print(f"Example not downloaded: {name}")
     example_manager.add_examples(datasets)
 
 
@@ -52,7 +61,7 @@ def get_url(name: str) -> str:
     return example_manager.get_remote_url(name)
 
 
-def load_example(example_name: str) -> Union[base.Example, builtin.LocalExample]:
+def load_example(example_name: str) -> Example | LocalExample:
     """Load example dataset instance."""
     example = example_manager.load(example_name)
     return example
@@ -66,7 +75,7 @@ def get_path(file_name: str) -> str:
         pth = example.get_path(file_name, verbose=False)
         if pth:
             return pth
-    print("{} is not a file in any installed dataset.".format(file_name))
+    print(f"{file_name} is not a file in any installed dataset.")
 
 
 def summary():
