@@ -1,30 +1,32 @@
-import unittest
-from ..arcgis_swm import ArcGISSwmIO
-from ...fileio import FileIO as psopen
-from .... import examples as pysal_examples
-import tempfile
 import os
+import tempfile
+
+import pytest
+
+from .... import examples as pysal_examples
+from ...fileio import FileIO as psopen
+from ..arcgis_swm import ArcGISSwmIO
 
 
-class test_ArcGISSwmIO(unittest.TestCase):
-    def setUp(self):
+class Testtest_ArcGISSwmIO:
+    def setup_method(self):
         self.test_file = test_file = pysal_examples.get_path("ohio.swm")
         self.obj = ArcGISSwmIO(test_file, "r")
 
     def test_close(self):
         f = self.obj
         f.close()
-        self.assertRaises(ValueError, f.read)
+        pytest.raises(ValueError, f.read)
 
     def test_read(self):
         w = self.obj.read()
-        self.assertEqual(88, w.n)
-        self.assertEqual(5.25, w.mean_neighbors)
-        self.assertEqual([1.0, 1.0, 1.0, 1.0], list(w[1].values()))
+        assert w.n == 88
+        assert w.mean_neighbors == 5.25
+        assert [1.0, 1.0, 1.0, 1.0] == list(w[1].values())
 
     def test_seek(self):
         self.test_read()
-        self.assertRaises(StopIteration, self.obj.read)
+        pytest.raises(StopIteration, self.obj.read)
         self.obj.seek(0)
         self.test_read()
 
@@ -37,9 +39,5 @@ class test_ArcGISSwmIO(unittest.TestCase):
         o.write(w)
         o.close()
         wnew = psopen(fname, "r").read()
-        self.assertEqual(wnew.pct_nonzero, w.pct_nonzero)
+        assert wnew.pct_nonzero == w.pct_nonzero
         os.remove(fname)
-
-
-if __name__ == "__main__":
-    unittest.main()
