@@ -1,31 +1,33 @@
-import unittest
-from ..mat import MatIO
-from .... import examples as pysal_examples
-from ...fileio import FileIO as psopen
-import tempfile
 import os
+import tempfile
 import warnings
 
+import pytest
 
-class test_MatIO(unittest.TestCase):
-    def setUp(self):
+from .... import examples as pysal_examples
+from ...fileio import FileIO as psopen
+from ..mat import MatIO
+
+
+class Testtest_MatIO:
+    def setup_method(self):
         self.test_file = test_file = pysal_examples.get_path("spat-sym-us.mat")
         self.obj = MatIO(test_file, "r")
 
     def test_close(self):
         f = self.obj
         f.close()
-        self.assertRaises(ValueError, f.read)
+        pytest.raises(ValueError, f.read)
 
     def test_read(self):
         w = self.obj.read()
-        self.assertEqual(46, w.n)
-        self.assertEqual(4.0869565217391308, w.mean_neighbors)
-        self.assertEqual([1.0, 1.0, 1.0, 1.0], list(w[1].values()))
+        assert w.n == 46
+        assert w.mean_neighbors == 4.0869565217391308
+        assert [1.0, 1.0, 1.0, 1.0] == list(w[1].values())
 
     def test_seek(self):
         self.test_read()
-        self.assertRaises(StopIteration, self.obj.read)
+        pytest.raises(StopIteration, self.obj.read)
         self.obj.seek(0)
         self.test_read()
 
@@ -42,9 +44,5 @@ class test_MatIO(unittest.TestCase):
                 assert issubclass(warn[0].category, FutureWarning)
         o.close()
         wnew = psopen(fname, "r").read()
-        self.assertEqual(wnew.pct_nonzero, w.pct_nonzero)
+        assert wnew.pct_nonzero == w.pct_nonzero
         os.remove(fname)
-
-
-if __name__ == "__main__":
-    unittest.main()
