@@ -1,40 +1,38 @@
-import unittest
-from ..mtx import MtxIO
-from ...fileio import FileIO as psopen
-from .... import examples as pysal_examples
-import tempfile
 import os
-import warnings
-import scipy.sparse as SP
+import tempfile
+
+import pytest
+
+from .... import examples as pysal_examples
+from ...fileio import FileIO as psopen
+from ..mtx import MtxIO
 
 
-class test_MtxIO(unittest.TestCase):
-    def setUp(self):
+class TesttestMtxIO:
+    def setup_method(self):
         self.test_file = test_file = pysal_examples.get_path("wmat.mtx")
         self.obj = MtxIO(test_file, "r")
 
     def test_close(self):
         f = self.obj
         f.close()
-        self.assertRaises(ValueError, f.read)
+        pytest.raises(ValueError, f.read)
 
     def test_read(self):
         w = self.obj.read()
-        self.assertEqual(49, w.n)
-        self.assertEqual(4.7346938775510203, w.mean_neighbors)
-        self.assertEqual(
-            [0.33329999999999999, 0.33329999999999999, 0.33329999999999999],
-            list(w[1].values()),
-        )
+        assert w.n == 49
+        assert w.mean_neighbors == 4.7346938775510203
+        assert [0.33329999999999999, 0.33329999999999999, 0.33329999999999999] == \
+            list(w[1].values())
         s0 = w.s0
         self.obj.seek(0)
         wsp = self.obj.read(sparse=True)
-        self.assertEqual(49, wsp.n)
-        self.assertEqual(s0, wsp.s0)
+        assert wsp.n == 49
+        assert s0 == wsp.s0
 
     def test_seek(self):
         self.test_read()
-        self.assertRaises(StopIteration, self.obj.read)
+        pytest.raises(StopIteration, self.obj.read)
         self.obj.seek(0)
         self.test_read()
 
@@ -50,11 +48,7 @@ class test_MtxIO(unittest.TestCase):
             o.close()
             wnew = psopen(fname, "r").read(sparse=i)
             if i:
-                self.assertEqual(wnew.s0, w.s0)
+                assert wnew.s0 == w.s0
             else:
-                self.assertEqual(wnew.pct_nonzero, w.pct_nonzero)
+                assert wnew.pct_nonzero == w.pct_nonzero
             os.remove(fname)
-
-
-if __name__ == "__main__":
-    unittest.main()
