@@ -1,30 +1,32 @@
-import unittest
-from ..wk1 import Wk1IO
+import os
+import tempfile
+
+import pytest
+
 from .... import examples as pysal_examples
 from ...fileio import FileIO as psopen
-import tempfile
-import os
+from ..wk1 import Wk1IO
 
 
-class test_Wk1IO(unittest.TestCase):
-    def setUp(self):
+class Testtest_Wk1IO:
+    def setup_method(self):
         self.test_file = test_file = pysal_examples.get_path("spat-sym-us.wk1")
         self.obj = Wk1IO(test_file, "r")
 
     def test_close(self):
         f = self.obj
         f.close()
-        self.assertRaises(ValueError, f.read)
+        pytest.raises(ValueError, f.read)
 
     def test_read(self):
         w = self.obj.read()
-        self.assertEqual(46, w.n)
-        self.assertEqual(4.0869565217391308, w.mean_neighbors)
-        self.assertEqual([1.0, 1.0, 1.0, 1.0], list(w[1].values()))
+        assert w.n == 46
+        assert w.mean_neighbors == 4.0869565217391308
+        assert [1.0, 1.0, 1.0, 1.0] == list(w[1].values())
 
     def test_seek(self):
         self.test_read()
-        self.assertRaises(StopIteration, self.obj.read)
+        pytest.raises(StopIteration, self.obj.read)
         self.obj.seek(0)
         self.test_read()
 
@@ -37,9 +39,6 @@ class test_Wk1IO(unittest.TestCase):
         o.write(w)
         o.close()
         wnew = psopen(fname, "r").read()
-        self.assertEqual(wnew.pct_nonzero, w.pct_nonzero)
+        assert wnew.pct_nonzero == w.pct_nonzero
         os.remove(fname)
 
-
-if __name__ == "__main__":
-    unittest.main()
