@@ -1,16 +1,15 @@
 import numpy as np
-from ..fileio import FileIO as psopen
-from ...common import pandas
 
 # import pysal_examples
 from ... import examples as pysal_examples
-import unittest as ut
+from ...common import pandas
+from ..fileio import FileIO as psopen
 
 PANDAS_EXTINCT = pandas is None
 
 
-class Test_Table(ut.TestCase):
-    def setUp(self):
+class TestTable:
+    def setup_method(self):
         self.filehandler = psopen(pysal_examples.get_path("columbus.dbf"))
         self.df = self.filehandler.to_df()
         self.filehandler.seek(0)
@@ -19,7 +18,6 @@ class Test_Table(ut.TestCase):
         self.csv_df = self.csvhandler.to_df()
         self.csvhandler.seek(0)
 
-    @ut.skipIf(PANDAS_EXTINCT, "Missing pandas.")
     def test_to_df(self):
         for column in self.csv_df.columns:
             if column.lower() == "name":
