@@ -1,4 +1,4 @@
-from .weights import *
+from .weights import *  # noqa I001
 from .distance import *
 from .contiguity import *
 from .spintW import *
@@ -7,4 +7,4 @@ from .user import *
 from .set_operations import *
 from .spatial_lag import *
 from .raster import *
-from .gabriel import Gabriel, Delaunay, Relative_Neighborhood 
+from .gabriel import Gabriel, Delaunay, Relative_Neighborhood
