@@ -1,39 +1,33 @@
 import os
-import unittest
-from .._contW_lists import ContiguityWeightsLists, ROOK, QUEEN
-from ..weights import W
-from ...io.fileio import FileIO as ps_open
-
-
-try:
-    import geopandas as gpd
-except ImportError:
-    gpd = None
 
+import geopandas as gpd
 
 from ... import examples as pysal_examples
+from ...io.fileio import FileIO as ps_open
+from .._contW_lists import QUEEN, ROOK, ContiguityWeightsLists
+from ..weights import W
 
 
-class TestContiguityWeights(unittest.TestCase):
-    def setUp(self):
-        """ Setup the binning contiguity weights"""
+class TestContiguityWeights:
+    def setup_method(self):
+        """Setup the binning contiguity weights"""
         shpObj = ps_open(pysal_examples.get_path("virginia.shp"), "r")
         self.binningW = ContiguityWeightsLists(shpObj, QUEEN)
         shpObj.close()
 
     def test_w_type(self):
-        self.assertTrue(isinstance(self.binningW, ContiguityWeightsLists))
+        assert isinstance(self.binningW, ContiguityWeightsLists)
 
-    def test_QUEEN(self):
-        self.assertEqual(QUEEN, 1)
+    def test_queen(self):
+        assert QUEEN == 1
 
-    def test_ROOK(self):
-        self.assertEqual(ROOK, 2)
+    def test_rook(self):
+        assert ROOK == 2
 
-    def test_ContiguityWeightsLists(self):
-        self.assertTrue(hasattr(self.binningW, "w"))
-        self.assertTrue(issubclass(dict, type(self.binningW.w)))
-        self.assertEqual(len(self.binningW.w), 136)
+    def test_contiguity_weights_lists(self):
+        assert hasattr(self.binningW, "w")
+        assert issubclass(dict, type(self.binningW.w))
+        assert len(self.binningW.w) == 136
 
     def test_nested_polygons(self):
         # load queen gal file created using Open Geoda.
@@ -48,7 +42,7 @@ class TestContiguityWeights(unittest.TestCase):
             pysalb_neighbors = pysalWb.neighbors[int(key)]
             geoda_neighbors.sort()
             pysalb_neighbors.sort()
-            self.assertEqual(geoda_neighbors, pysalb_neighbors)
+            assert geoda_neighbors == pysalb_neighbors
 
     def test_true_rook(self):
         # load queen gal file created using Open Geoda.
@@ -62,7 +56,7 @@ class TestContiguityWeights(unittest.TestCase):
             pysalb_neighbors = pysalWb.neighbors[int(key)]
             geoda_neighbors.sort()
             pysalb_neighbors.sort()
-            self.assertEqual(geoda_neighbors, pysalb_neighbors)
+            assert geoda_neighbors == pysalb_neighbors
 
     def test_true_rook2(self):
         # load queen gal file created using Open Geoda.
@@ -78,7 +72,7 @@ class TestContiguityWeights(unittest.TestCase):
             pysalb_neighbors = pysalWb.neighbors[int(key)]
             geoda_neighbors.sort()
             pysalb_neighbors.sort()
-            self.assertEqual(geoda_neighbors, pysalb_neighbors)
+            assert geoda_neighbors == pysalb_neighbors
 
     def test_true_rook3(self):
         # load queen gal file created using Open Geoda.
@@ -91,24 +85,23 @@ class TestContiguityWeights(unittest.TestCase):
             pysalb_neighbors = pysalWb.neighbors[int(key)]
             geoda_neighbors.sort()
             pysalb_neighbors.sort()
-            self.assertEqual(geoda_neighbors, pysalb_neighbors)
+            assert geoda_neighbors == pysalb_neighbors
 
-    @unittest.skipIf(gpd is None, "geopandas is missing in the testing environment")
     def test_shapely(self):
         pysalneighbs = ContiguityWeightsLists(
             ps_open(pysal_examples.get_path("virginia.shp")), ROOK
         )
         gdf = gpd.read_file(pysal_examples.get_path("virginia.shp"))
         shplyneighbs = ContiguityWeightsLists(gdf.geometry.tolist(), ROOK)
-        self.assertEqual(pysalneighbs.w, shplyneighbs.w)
+        assert pysalneighbs.w == shplyneighbs.w
         pysalneighbs = ContiguityWeightsLists(
             ps_open(pysal_examples.get_path("virginia.shp")), QUEEN
         )
         shplyneighbs = ContiguityWeightsLists(gdf.geometry.tolist(), QUEEN)
-        self.assertEqual(pysalneighbs.w, shplyneighbs.w)
+        assert pysalneighbs.w == shplyneighbs.w
 
     def build_W(self, shapefile, type, idVariable=None):
-        """ Building 2 W's the hard way.  We need to do this so we can test both rtree and binning """
+        """Building 2 W's the hard way.  We need to do this so we can test both rtree and binning"""
         dbname = os.path.splitext(shapefile)[0] + ".dbf"
         db = ps_open(dbname)
         shpObj = ps_open(shapefile)
@@ -117,7 +110,7 @@ class TestContiguityWeights(unittest.TestCase):
         weights = {}
         if idVariable:
             ids = db.by_col[idVariable]
-            self.assertEqual(len(ids), len(set(ids)))
+            assert len(ids) == len(set(ids))
             for key in neighbor_data:
                 id = ids[key]
                 if id not in neighbors:
@@ -130,11 +123,3 @@ class TestContiguityWeights(unittest.TestCase):
             neighbors[key] = list(neighbors[key])
             binningW = W(neighbors)
         return binningW
-
-
-# suite = unittest.TestLoader().loadTestsFromTestCase(_TestContiguityWeights)
-
-if __name__ == "__main__":
-    # runner = unittest.TextTestRunner()
-    # runner.run(suite)
-    unittest.main()
