@@ -1,23 +1,23 @@
 import os
 import tempfile
+import warnings
 
-import unittest
-import pytest
-from ..weights import W, WSP, _LabelEncoder
-from .. import util
-from ..util import WSP2W, lat2W
-from ..contiguity import Rook
-from ...io.fileio import FileIO as psopen
-from ... import examples
-from ..distance import KNN
+import geopandas
 import numpy as np
+import pytest
 import scipy.sparse
 
-NPTA3E = np.testing.assert_array_almost_equal
+from ... import examples
+from ...io.fileio import FileIO as psopen
+from .. import util
+from ..contiguity import Rook
+from ..distance import KNN
+from ..util import WSP2W, lat2W
+from ..weights import WSP, W, _LabelEncoder
 
 
-class TestW(unittest.TestCase):
-    def setUp(self):
+class TestW:
+    def setup_method(self):
         self.w = Rook.from_shapefile(
             examples.get_path("10740.shp"), silence_warnings=True
         )
@@ -48,64 +48,61 @@ class TestW(unittest.TestCase):
         self.w3x3 = util.lat2W(3, 3)
         self.w_islands = W({0: [1], 1: [0, 2], 2: [1], 3: []})
 
-    def test_W(self):
+    def test_w(self):
         w = W(self.neighbors, self.weights, silence_warnings=True)
-        self.assertEqual(w.pct_nonzero, 29.62962962962963)
+        assert w.pct_nonzero == 29.62962962962963
 
     def test___getitem__(self):
-        self.assertEqual(self.w[0], {1: 1.0, 4: 1.0, 101: 1.0, 85: 1.0, 5: 1.0})
+        assert self.w[0] == {1: 1.0, 4: 1.0, 101: 1.0, 85: 1.0, 5: 1.0}
 
     def test___init__(self):
         w = W(self.neighbors, self.weights, silence_warnings=True)
-        self.assertEqual(w.pct_nonzero, 29.62962962962963)
+        assert w.pct_nonzero == 29.62962962962963
 
     def test___iter__(self):
         w = lat2W(3, 3)
         res = {}
         for i, wi in enumerate(w):
             res[i] = wi
-        self.assertEqual(res[0], (0, {1: 1.0, 3: 1.0}))
-        self.assertEqual(res[8], (8, {5: 1.0, 7: 1.0}))
+        assert res[0] == (0, {1: 1.0, 3: 1.0})
+        assert res[8] == (8, {5: 1.0, 7: 1.0})
 
     def test_asymmetries(self):
         w = lat2W(3, 3)
         w.transform = "r"
         result = w.asymmetry()
-        self.assertEqual(
-            result,
-            [
-                (0, 1),
-                (0, 3),
-                (1, 0),
-                (1, 2),
-                (1, 4),
-                (2, 1),
-                (2, 5),
-                (3, 0),
-                (3, 4),
-                (3, 6),
-                (4, 1),
-                (4, 3),
-                (4, 5),
-                (4, 7),
-                (5, 2),
-                (5, 4),
-                (5, 8),
-                (6, 3),
-                (6, 7),
-                (7, 4),
-                (7, 6),
-                (7, 8),
-                (8, 5),
-                (8, 7),
-            ],
-        )
+        assert result == [
+            (0, 1),
+            (0, 3),
+            (1, 0),
+            (1, 2),
+            (1, 4),
+            (2, 1),
+            (2, 5),
+            (3, 0),
+            (3, 4),
+            (3, 6),
+            (4, 1),
+            (4, 3),
+            (4, 5),
+            (4, 7),
+            (5, 2),
+            (5, 4),
+            (5, 8),
+            (6, 3),
+            (6, 7),
+            (7, 4),
+            (7, 6),
+            (7, 8),
+            (8, 5),
+            (8, 7),
+        ]
 
     def test_asymmetry(self):
         w = lat2W(3, 3)
-        self.assertEqual(w.asymmetry(), [])
+        assert w.asymmetry() == []
         w.transform = "r"
-        self.assertFalse(w.asymmetry() == [])
+        assert not w.asymmetry() == []
 
     def test_asymmetry_string_index(self):
         neighbors = {
@@ -159,22 +156,20 @@ class TestW(unittest.TestCase):
 
     def test_cardinalities(self):
         w = lat2W(3, 3)
-        self.assertEqual(
-            w.cardinalities, {0: 2, 1: 3, 2: 2, 3: 3, 4: 4, 5: 3, 6: 2, 7: 3, 8: 2}
-        )
+        assert w.cardinalities == {0: 2, 1: 3, 2: 2, 3: 3, 4: 4, 5: 3, 6: 2, 7: 3, 8: 2}
 
-    def test_diagW2(self):
-        NPTA3E(
+    def test_diag_w2(self):
+        np.testing.assert_array_almost_equal(
             self.w3x3.diagW2, np.array([2.0, 3.0, 2.0, 3.0, 4.0, 3.0, 2.0, 3.0, 2.0])
         )
 
-    def test_diagWtW(self):
-        NPTA3E(
+    def test_diag_wt_w(self):
+        np.testing.assert_array_almost_equal(
             self.w3x3.diagW2, np.array([2.0, 3.0, 2.0, 3.0, 4.0, 3.0, 2.0, 3.0, 2.0])
         )
 
-    def test_diagWtW_WW(self):
-        NPTA3E(
+    def test_diag_wt_w_ww(self):
+        np.testing.assert_array_almost_equal(
             self.w3x3.diagWtW_WW,
             np.array([4.0, 6.0, 4.0, 6.0, 8.0, 6.0, 4.0, 6.0, 4.0]),
         )
@@ -196,13 +191,13 @@ class TestW(unittest.TestCase):
         ids = list(range(9))
 
         wf1, ids1 = self.w3x3.full()
-        NPTA3E(wf1, wf)
-        self.assertEqual(ids1, ids)
+        np.testing.assert_array_almost_equal(wf1, wf)
+        assert ids1 == ids
 
     def test_get_transform(self):
-        self.assertEqual(self.w3x3.transform, "O")
+        assert self.w3x3.transform == "O"
         self.w3x3.transform = "r"
-        self.assertEqual(self.w3x3.transform, "R")
+        assert self.w3x3.transform == "R"
         self.w3x3.transform = "b"
 
     def test_higher_order(self):
@@ -237,7 +232,7 @@ class TestW(unittest.TestCase):
             k: {ne: weights[k][i] for i, ne in enumerate(v)}
             for k, v in list(w2.neighbors.items())
         }
-        self.assertEqual(test_wneighbs, wneighbs)
+        assert test_wneighbs == wneighbs
 
     def test_histogram(self):
         hist = [
@@ -258,43 +253,43 @@ class TestW(unittest.TestCase):
             (14, 0),
             (15, 1),
         ]
-        self.assertEqual(self.w.histogram, hist)
+        assert self.w.histogram == hist
 
     def test_id2i(self):
         id2i = {0: 0, 1: 1, 2: 2, 3: 3, 4: 4, 5: 5, 6: 6, 7: 7, 8: 8}
-        self.assertEqual(self.w3x3.id2i, id2i)
+        assert self.w3x3.id2i == id2i
 
     def test_id_order_set(self):
         w = W(neighbors={"a": ["b"], "b": ["a", "c"], "c": ["b"]})
-        self.assertFalse(w.id_order_set)
+        assert not w.id_order_set
 
     def test_islands(self):
         w = W(
             neighbors={"a": ["b"], "b": ["a", "c"], "c": ["b"], "d": []},
             silence_warnings=True,
         )
-        self.assertEqual(w.islands, ["d"])
-        self.assertEqual(self.w3x3.islands, [])
+        assert w.islands == ["d"]
+        assert self.w3x3.islands == []
 
     def test_max_neighbors(self):
         w = W(
             neighbors={"a": ["b"], "b": ["a", "c"], "c": ["b"], "d": []},
             silence_warnings=True,
         )
-        self.assertEqual(w.max_neighbors, 2)
-        self.assertEqual(self.w3x3.max_neighbors, 4)
+        assert w.max_neighbors == 2
+        assert self.w3x3.max_neighbors == 4
 
     def test_mean_neighbors(self):
         w = util.lat2W()
-        self.assertEqual(w.mean_neighbors, 3.2)
+        assert w.mean_neighbors == 3.2
 
     def test_min_neighbors(self):
         w = util.lat2W()
-        self.assertEqual(w.min_neighbors, 2)
+        assert w.min_neighbors == 2
 
     def test_n(self):
         w = util.lat2W()
-        self.assertEqual(w.n, 25)
+        assert w.n == 25
 
     def test_neighbor_offsets(self):
         d = {
@@ -309,10 +304,10 @@ class TestW(unittest.TestCase):
             8: [5, 7],
         }
 
-        self.assertEqual(self.w3x3.neighbor_offsets, d)
+        assert self.w3x3.neighbor_offsets == d
 
     def test_nonzero(self):
-        self.assertEqual(self.w3x3.nonzero, 24)
+        assert self.w3x3.nonzero == 24
 
     def test_order(self):
         w = util.lat2W(3, 3)
@@ -327,35 +322,35 @@ class TestW(unittest.TestCase):
             7: [3, 2, 3, 2, 1, 2, 1, -1, 1],
             8: [0, 3, 2, 3, 2, 1, 2, 1, -1],
         }
-        self.assertEqual(util.order(w), o)
+        assert util.order(w) == o
 
     def test_pct_nonzero(self):
-        self.assertEqual(self.w3x3.pct_nonzero, 29.62962962962963)
+        assert self.w3x3.pct_nonzero == 29.62962962962963
 
     def test_s0(self):
-        self.assertEqual(self.w3x3.s0, 24.0)
+        assert self.w3x3.s0 == 24.0
 
     def test_s1(self):
-        self.assertEqual(self.w3x3.s1, 48.0)
+        assert self.w3x3.s1 == 48.0
 
     def test_s2(self):
-        self.assertEqual(self.w3x3.s2, 272.0)
+        assert self.w3x3.s2 == 272.0
 
     def test_s2array(self):
         s2a = np.array(
             [[16.0], [36.0], [16.0], [36.0], [64.0], [36.0], [16.0], [36.0], [16.0]]
         )
-        NPTA3E(self.w3x3.s2array, s2a)
+        np.testing.assert_array_almost_equal(self.w3x3.s2array, s2a)
 
     def test_sd(self):
-        self.assertEqual(self.w3x3.sd, 0.66666666666666663)
+        assert self.w3x3.sd == 0.66666666666666663
 
     def test_set_transform(self):
         w = util.lat2W(2, 2)
-        self.assertEqual(w.transform, "O")
-        self.assertEqual(w.weights[0], [1.0, 1.0])
+        assert w.transform == "O"
+        assert w.weights[0] == [1.0, 1.0]
         w.transform = "r"
-        self.assertEqual(w.weights[0], [0.5, 0.5])
+        assert w.weights[0] == [0.5, 0.5]
 
     def test_shimbel(self):
         d = {
@@ -369,19 +364,19 @@ class TestW(unittest.TestCase):
             7: [3, 2, 3, 2, 1, 2, 1, -1, 1],
             8: [4, 3, 2, 3, 2, 1, 2, 1, -1],
         }
-        self.assertEqual(util.shimbel(self.w3x3), d)
+        assert util.shimbel(self.w3x3) == d
 
     def test_sparse(self):
-        self.assertEqual(self.w3x3.sparse.nnz, 24)
+        assert self.w3x3.sparse.nnz == 24
 
-    def test_trcW2(self):
-        self.assertEqual(self.w3x3.trcW2, 24.0)
+    def test_trc_w2(self):
+        assert self.w3x3.trcW2 == 24.0
 
-    def test_trcWtW(self):
-        self.assertEqual(self.w3x3.trcWtW, 24.0)
+    def test_trc_wt_w(self):
+        assert self.w3x3.trcWtW == 24.0
 
-    def test_trcWtW_WW(self):
-        self.assertEqual(self.w3x3.trcWtW_WW, 48.0)
+    def test_trc_wt_w_ww(self):
+        assert self.w3x3.trcWtW_WW == 48.0
 
     def test_symmetrize(self):
         symm = self.w.symmetrize()
@@ -408,21 +403,28 @@ class TestW(unittest.TestCase):
             new = W.from_file(path)
         np.testing.assert_array_equal(self.w.sparse.toarray(), new.sparse.toarray())
 
+    def test_plot(self):
+        pytest.importorskip("matplotlib")
+        df = geopandas.read_file(examples.get_path("10740.shp"))
+        with warnings.catch_warnings(record=True) as record:
+            self.w.plot(df)
+        assert len(record) == 0
+
     def test_to_sparse(self):
         sparse = self.w_islands.to_sparse()
         np.testing.assert_array_equal(sparse.data, [1, 1, 1, 1, 0])
         np.testing.assert_array_equal(sparse.row, [0, 1, 1, 2, 3])
         np.testing.assert_array_equal(sparse.col, [1, 0, 2, 1, 3])
         sparse = self.w_islands.to_sparse("bsr")
-        self.assertIsInstance(sparse, scipy.sparse.bsr_array)
+        assert isinstance(sparse, scipy.sparse.bsr_array)
         sparse = self.w_islands.to_sparse("csr")
-        self.assertIsInstance(sparse, scipy.sparse.csr_array)
+        assert isinstance(sparse, scipy.sparse.csr_array)
         sparse = self.w_islands.to_sparse("coo")
-        self.assertIsInstance(sparse, scipy.sparse.coo_array)
+        assert isinstance(sparse, scipy.sparse.coo_array)
         sparse = self.w_islands.to_sparse("csc")
-        self.assertIsInstance(sparse, scipy.sparse.csc_array)
+        assert isinstance(sparse, scipy.sparse.csc_array)
         sparse = self.w_islands.to_sparse()
-        self.assertIsInstance(sparse, scipy.sparse.coo_array)
+        assert isinstance(sparse, scipy.sparse.coo_array)
 
     def test_sparse_fmt(self):
         with pytest.raises(ValueError) as exc_info:
@@ -431,14 +433,14 @@ class TestW(unittest.TestCase):
     def test_from_sparse(self):
         sparse = self.w_islands.to_sparse()
         w = W.from_sparse(sparse)
-        self.assertEqual(w.n, 4)
-        self.assertEqual(len(w.islands), 0)
-        self.assertEqual(w.neighbors[3], [3])
+        assert w.n == 4
+        assert len(w.islands) == 0
+        assert w.neighbors[3] == [3]
 
 
-class Test_WSP_Back_To_W(unittest.TestCase):
+class Test_WSP_Back_To_W:
     # Test to make sure we get back to the same W functionality
-    def setUp(self):
+    def setup_method(self):
         self.w = Rook.from_shapefile(
             examples.get_path("10740.shp"), silence_warnings=True
         )
@@ -472,83 +474,78 @@ class Test_WSP_Back_To_W(unittest.TestCase):
         w3x3 = WSP(self.w3x3.sparse, self.w3x3.id_order)
         self.w3x3 = WSP2W(w3x3)
 
-    def test_W(self):
+    def test_w(self):
         w = W(self.neighbors, self.weights, silence_warnings=True)
-        self.assertEqual(w.pct_nonzero, 29.62962962962963)
+        assert w.pct_nonzero == 29.62962962962963
 
     def test___getitem__(self):
-        self.assertEqual(self.w[0], {1: 1.0, 4: 1.0, 101: 1.0, 85: 1.0, 5: 1.0})
+        assert self.w[0] == {1: 1.0, 4: 1.0, 101: 1.0, 85: 1.0, 5: 1.0}
 
     def test___init__(self):
         w = W(self.neighbors, self.weights, silence_warnings=True)
-        self.assertEqual(w.pct_nonzero, 29.62962962962963)
+        assert w.pct_nonzero == 29.62962962962963
 
     def test___iter__(self):
         w = util.lat2W(3, 3)
         res = {}
         for i, wi in enumerate(w):
             res[i] = wi
-        self.assertEqual(res[0], (0, {1: 1.0, 3: 1.0}))
-        self.assertEqual(res[8], (8, {5: 1.0, 7: 1.0}))
+        assert res[0] == (0, {1: 1.0, 3: 1.0})
+        assert res[8] == (8, {5: 1.0, 7: 1.0})
 
     def test_asymmetries(self):
         w = util.lat2W(3, 3)
         w.transform = "r"
         result = w.asymmetry()
-        self.assertEqual(
-            result,
-            [
-                (0, 1),
-                (0, 3),
-                (1, 0),
-                (1, 2),
-                (1, 4),
-                (2, 1),
-                (2, 5),
-                (3, 0),
-                (3, 4),
-                (3, 6),
-                (4, 1),
-                (4, 3),
-                (4, 5),
-                (4, 7),
-                (5, 2),
-                (5, 4),
-                (5, 8),
-                (6, 3),
-                (6, 7),
-                (7, 4),
-                (7, 6),
-                (7, 8),
-                (8, 5),
-                (8, 7),
-            ],
-        )
+        assert result == [
+            (0, 1),
+            (0, 3),
+            (1, 0),
+            (1, 2),
+            (1, 4),
+            (2, 1),
+            (2, 5),
+            (3, 0),
+            (3, 4),
+            (3, 6),
+            (4, 1),
+            (4, 3),
+            (4, 5),
+            (4, 7),
+            (5, 2),
+            (5, 4),
+            (5, 8),
+            (6, 3),
+            (6, 7),
+            (7, 4),
+            (7, 6),
+            (7, 8),
+            (8, 5),
+            (8, 7),
+        ]
 
     def test_asymmetry(self):
         w = util.lat2W(3, 3)
-        self.assertEqual(w.asymmetry(), [])
+        assert w.asymmetry() == []
         w.transform = "r"
-        self.assertFalse(w.asymmetry() == [])
+        assert not w.asymmetry() == []
 
     def test_cardinalities(self):
         w = util.lat2W(3, 3)
-        self.assertEqual(
-            w.cardinalities, {0: 2, 1: 3, 2: 2, 3: 3, 4: 4, 5: 3, 6: 2, 7: 3, 8: 2}
-        )
+        assert w.cardinalities == {0: 2, 1: 3, 2: 2, 3: 3, 4: 4, 5: 3, 6: 2, 7: 3, 8: 2}
 
-    def test_diagW2(self):
-        NPTA3E(
+    def test_diag_w2(self):
+        np.testing.assert_array_almost_equal(
             self.w3x3.diagW2, np.array([2.0, 3.0, 2.0, 3.0, 4.0, 3.0, 2.0, 3.0, 2.0])
         )
 
-    def test_diagWtW(self):
-        NPTA3E(
+    def test_diag_wt_w(self):
+        np.testing.assert_array_almost_equal(
             self.w3x3.diagW2, np.array([2.0, 3.0, 2.0, 3.0, 4.0, 3.0, 2.0, 3.0, 2.0])
         )
 
-    def test_diagWtW_WW(self):
-        NPTA3E(
+    def test_diag_wt_w_ww(self):
+        np.testing.assert_array_almost_equal(
             self.w3x3.diagWtW_WW,
             np.array([4.0, 6.0, 4.0, 6.0, 8.0, 6.0, 4.0, 6.0, 4.0]),
         )
@@ -570,13 +567,13 @@ class Test_WSP_Back_To_W(unittest.TestCase):
         ids = list(range(9))
 
         wf1, ids1 = self.w3x3.full()
-        NPTA3E(wf1, wf)
-        self.assertEqual(ids1, ids)
+        np.testing.assert_array_almost_equal(wf1, wf)
+        assert ids1 == ids
 
     def test_get_transform(self):
-        self.assertEqual(self.w3x3.transform, "O")
+        assert self.w3x3.transform == "O"
         self.w3x3.transform = "r"
-        self.assertEqual(self.w3x3.transform, "R")
+        assert self.w3x3.transform == "R"
         self.w3x3.transform = "b"
 
     def test_higher_order(self):
@@ -611,7 +608,7 @@ class Test_WSP_Back_To_W(unittest.TestCase):
             k: {ne: w2.weights[k][i] for i, ne in enumerate(v)}
             for k, v in list(w2.neighbors.items())
         }
-        self.assertEqual(test_wneighbs, wneighbs)
+        assert test_wneighbs == wneighbs
 
     def test_histogram(self):
         hist = [
@@ -632,46 +629,46 @@ class Test_WSP_Back_To_W(unittest.TestCase):
             (14, 0),
             (15, 1),
         ]
-        self.assertEqual(self.w.histogram, hist)
+        assert self.w.histogram == hist
 
     def test_id2i(self):
         id2i = {0: 0, 1: 1, 2: 2, 3: 3, 4: 4, 5: 5, 6: 6, 7: 7, 8: 8}
-        self.assertEqual(self.w3x3.id2i, id2i)
+        assert self.w3x3.id2i == id2i
 
     def test_id_order_set(self):
         w = W(neighbors={"a": ["b"], "b": ["a", "c"], "c": ["b"]})
-        self.assertFalse(w.id_order_set)
+        assert not w.id_order_set
 
     def test_islands(self):
         w = W(
             neighbors={"a": ["b"], "b": ["a", "c"], "c": ["b"], "d": []},
             silence_warnings=True,
         )
-        self.assertEqual(w.islands, ["d"])
-        self.assertEqual(self.w3x3.islands, [])
+        assert w.islands == ["d"]
+        assert self.w3x3.islands == []
 
     def test_max_neighbors(self):
         w = W(
             neighbors={"a": ["b"], "b": ["a", "c"], "c": ["b"], "d": []},
             silence_warnings=True,
         )
-        self.assertEqual(w.max_neighbors, 2)
-        self.assertEqual(self.w3x3.max_neighbors, 4)
+        assert w.max_neighbors == 2
+        assert self.w3x3.max_neighbors == 4
 
     def test_mean_neighbors(self):
         w = util.lat2W()
-        self.assertEqual(w.mean_neighbors, 3.2)
+        assert w.mean_neighbors == 3.2
 
     def test_min_neighbors(self):
         w = util.lat2W()
-        self.assertEqual(w.min_neighbors, 2)
+        assert w.min_neighbors == 2
 
     def test_n(self):
         w = util.lat2W()
-        self.assertEqual(w.n, 25)
+        assert w.n == 25
 
     def test_nonzero(self):
-        self.assertEqual(self.w3x3.nonzero, 24)
+        assert self.w3x3.nonzero == 24
 
     def test_order(self):
         w = util.lat2W(3, 3)
@@ -686,35 +683,35 @@ class Test_WSP_Back_To_W(unittest.TestCase):
             7: [3, 2, 3, 2, 1, 2, 1, -1, 1],
             8: [0, 3, 2, 3, 2, 1, 2, 1, -1],
         }
-        self.assertEqual(util.order(w), o)
+        assert util.order(w) == o
 
     def test_pct_nonzero(self):
-        self.assertEqual(self.w3x3.pct_nonzero, 29.62962962962963)
+        assert self.w3x3.pct_nonzero == 29.62962962962963
 
     def test_s0(self):
-        self.assertEqual(self.w3x3.s0, 24.0)
+        assert self.w3x3.s0 == 24.0
 
     def test_s1(self):
-        self.assertEqual(self.w3x3.s1, 48.0)
+        assert self.w3x3.s1 == 48.0
 
     def test_s2(self):
-        self.assertEqual(self.w3x3.s2, 272.0)
+        assert self.w3x3.s2 == 272.0
 
     def test_s2array(self):
         s2a = np.array(
             [[16.0], [36.0], [16.0], [36.0], [64.0], [36.0], [16.0], [36.0], [16.0]]
         )
-        NPTA3E(self.w3x3.s2array, s2a)
+        np.testing.assert_array_almost_equal(self.w3x3.s2array, s2a)
 
     def test_sd(self):
-        self.assertEqual(self.w3x3.sd, 0.66666666666666663)
+        assert self.w3x3.sd == 0.66666666666666663
 
     def test_set_transform(self):
         w = util.lat2W(2, 2)
-        self.assertEqual(w.transform, "O")
-        self.assertEqual(w.weights[0], [1.0, 1.0])
+        assert w.transform == "O"
+        assert w.weights[0] == [1.0, 1.0]
         w.transform = "r"
-        self.assertEqual(w.weights[0], [0.5, 0.5])
+        assert w.weights[0] == [0.5, 0.5]
 
     def test_shimbel(self):
         d = {
@@ -728,53 +725,53 @@ class Test_WSP_Back_To_W(unittest.TestCase):
             7: [3, 2, 3, 2, 1, 2, 1, -1, 1],
             8: [4, 3, 2, 3, 2, 1, 2, 1, -1],
         }
-        self.assertEqual(util.shimbel(self.w3x3), d)
+        assert util.shimbel(self.w3x3) == d
 
     def test_sparse(self):
-        self.assertEqual(self.w3x3.sparse.nnz, 24)
+        assert self.w3x3.sparse.nnz == 24
 
-    def test_trcW2(self):
-        self.assertEqual(self.w3x3.trcW2, 24.0)
+    def test_trc_w2(self):
+        assert self.w3x3.trcW2 == 24.0
 
-    def test_trcWtW(self):
-        self.assertEqual(self.w3x3.trcWtW, 24.0)
+    def test_trc_wt_w(self):
+        assert self.w3x3.trcWtW == 24.0
 
-    def test_trcWtW_WW(self):
-        self.assertEqual(self.w3x3.trcWtW_WW, 48.0)
+    def test_trc_wt_w_ww(self):
+        assert self.w3x3.trcWtW_WW == 48.0
 
 
-class TestWSP(unittest.TestCase):
-    def setUp(self):
+class TestWSP:
+    def setup_method(self):
         self.w = psopen(examples.get_path("sids2.gal")).read()
         self.wsp = WSP(self.w.sparse, self.w.id_order)
         w3x3 = util.lat2W(3, 3)
         self.w3x3 = WSP(w3x3.sparse)
 
-    def test_WSP(self):
-        self.assertEqual(self.w.id_order, self.wsp.id_order)
-        self.assertEqual(self.w.n, self.wsp.n)
+    def test_wsp(self):
+        assert self.w.id_order == self.wsp.id_order
+        assert self.w.n == self.wsp.n
         np.testing.assert_array_equal(
             self.w.sparse.todense(), self.wsp.sparse.todense()
         )
 
-    def test_diagWtW_WW(self):
-        NPTA3E(
+    def test_diag_wt_w_ww(self):
+        np.testing.assert_array_almost_equal(
             self.w3x3.diagWtW_WW,
             np.array([4.0, 6.0, 4.0, 6.0, 8.0, 6.0, 4.0, 6.0, 4.0]),
         )
 
-    def test_trcWtW_WW(self):
-        self.assertEqual(self.w3x3.trcWtW_WW, 48.0)
+    def test_trc_wt_w_ww(self):
+        assert self.w3x3.trcWtW_WW == 48.0
 
     def test_s0(self):
-        self.assertEqual(self.w3x3.s0, 24.0)
+        assert self.w3x3.s0 == 24.0
 
-    def test_from_WSP(self):
+    def test_from_wsp(self):
         w = W.from_WSP(self.wsp)
-        self.assertEqual(w.n, 100)
-        self.assertEqual(w.pct_nonzero, 4.62)
+        assert w.n == 100
+        assert w.pct_nonzero == 4.62
 
-    def test_LabelEncoder(self):
+    def test_label_encoder(self):
         le = _LabelEncoder()
         le.fit(["NY", "CA", "NY", "CA", "TX", "TX"])
         np.testing.assert_equal(le.classes_, np.array(["CA", "NY", "TX"]))
@@ -782,7 +779,3 @@ class TestWSP(unittest.TestCase):
             le.transform(["NY", "CA", "NY", "CA", "TX", "TX"]),
             np.array([1, 0, 1, 0, 2, 2]),
         )
-
-
-if __name__ == "__main__":
-    unittest.main()
