@@ -1,16 +1,17 @@
-import unittest
+import os
+import tempfile
+
 import libpysal
-import tempfile, os
 
 
-class TestWIO(unittest.TestCase):
-    def setUp(self):
+class TestWIO:
+    def setup_method(self):
         self.swmFile1 = libpysal.examples.get_path("ohio.swm")
         self.swmFile2 = libpysal.examples.get_path("us48_CONTIGUITY_EDGES_ONLY.swm")
         self.swmFile3 = libpysal.examples.get_path("us48_INVERSE_DISTANCE.swm")
         self.files = [self.swmFile1, self.swmFile2, self.swmFile3]
 
-    def test_SWMIO(self):
+    def test_swmio(self):
         for file in self.files:
             f1 = libpysal.io.open(file)
             w1 = f1.read()
@@ -27,8 +28,4 @@ class TestWIO(unittest.TestCase):
             f2.close()
             w2 = libpysal.io.open(fname, "r").read()
             assert w1.pct_nonzero == w2.pct_nonzero
-            os.remove(fname)
-
-
-if __name__ == "__main__":
-    unittest.main()
+            os.remove(fname)
\ No newline at end of file
